"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LocalStorage_1 = require("./LocalStore/LocalStorage");
// import  { FirebaseStorage  }   from './FireStore/FirebaseStorage'
var moment = require('moment');
var DEBUG = false;
var log = DEBUG ? console.log : function () { };
var Persistence;
(function (Persistence) {
    Persistence.LocalStore = LocalStorage_1.LocalStorage;
    Persistence.FireStore = null;
    /**
       * @param {String} key - a key for a stored object
       * @param {IPersistenceStore} store - the persistence method used for the cache
       * @return {Object} a promise for an empty object, the cache is expired
       */
    Persistence.expireItem = function (key, store) {
        if (store === void 0) { store = Persistence.LocalStore; }
        return new Promise(function (resolve, reject) {
            var cacheObject = {
                expires: moment().subtract(1, 'second').toISOString(),
                value: {},
            };
            store.setItem(key, cacheObject).then(function (data) {
                log('cache: ' + key + ' expired.');
                resolve(data.value);
            });
        });
    };
    /**
       * @param {String} key - a key for a stored object
       * @param {Object} value - a an object to be persisted
       * @param {String} expires - an ISO string for when the cache expires
       * @param {IPersistenceStore} store - the persistence method used for the cache
       * @return {Object} a promise for the object at the given key
       */
    Persistence.setItem = function (key, value, expires, store) {
        if (expires === void 0) { expires = moment().add(15, 'seconds').toISOString(); }
        if (store === void 0) { store = Persistence.LocalStore; }
        return new Promise(function (resolve, reject) {
            var cacheObject = {
                expires: expires,
                value: value,
            };
            store.setItem(key, cacheObject).then(function (data) {
                log('cache: ' + key + ' set.');
                resolve(data.value);
            });
        });
    };
    /**
       * @param {String} key - a key for a stored object
       * @param {IPersistenceStore} store - the persistence method used for the cache
       * @return {Object} a promise for the object at the given key
       */
    Persistence.getItem = function (key, store) {
        if (store === void 0) { store = Persistence.LocalStore; }
        return new Promise(function (resolve, reject) {
            store.getItem(key).then(function (data) {
                if (moment().isAfter(moment(data.expires))) {
                    log('cache: ' + key + ' has expired.');
                    resolve(null);
                }
                else {
                    log('cache: ' + key + ' hit.');
                    resolve(data.value);
                }
            });
        });
    };
})(Persistence = exports.Persistence || (exports.Persistence = {}));
//# sourceMappingURL=Persistence.js.map